package inheritance.abstracts;

/**
 * This is an abstract base class containing common code for
 * sub classes. Can't instantiate this class (shouldn't instantiate)
 * 
 * This show how to collect common code in one
 * place. We must avoid same code in many places (duplicate code)
 * 
 * @author hajo
 */
public abstract class AbstractGameCharacter {

    private final int id;
    private int xPos;
    private int yPos;
    private boolean alive = true;
    private int health;
    private int attack;

    public AbstractGameCharacter(int id, int xPos, int yPos, int health, int attack) {
        this.id = id;
        this.xPos = xPos;
        this.yPos = yPos;
        this.health = health;
        this.attack = attack;
    }
    
    // This is unique for each subclass (this forces
    // all subclasses to implement a move metod else
    // they must be abstract too).
    public abstract void move();

    public int getId() {
        return id;
    }
     
    public int getxPos() {
        return xPos;
    }

    public void setxPos(int xPos) {
        this.xPos = xPos;
    }

    public int getyPos() {
        return yPos;
    }

    public void setyPos(int yPos) {
        this.yPos = yPos;
    }

    public boolean isAlive() {
        return alive;
    }

    public void setAlive(boolean alive) {
        this.alive = alive;
    }

    public int getHealth() {
        return health;
    }

    public void setHealth(int health) {
        this.health = health;
    }

    public int getAttack() {
        return attack;
    }

    public void setAttack(int attack) {
        this.attack = attack;
    } 
}
